pub enum NotationBreakPolicy {
Preserve,
KeepVoltaTogether,
KeepRepeatsTogether,
}Expand description
Policy for preserving repeat-ending notation while systems are reflowed.
Variants
Preserve
Keep the score’s normal automatic system breaks.
KeepVoltaTogether
Keep each contiguous volta ending in one system when it fits.
KeepRepeatsTogether
Keep each repeat section on one page when it fits the page capacity.