pub fn compute_layout(score: &Score, config: &LayoutConfig) -> LayoutResultExpand description
Compute a LayoutResult for the given score and configuration.
The result is independent of pixel dimensions so any renderer can consume it.
pub fn compute_layout(score: &Score, config: &LayoutConfig) -> LayoutResultCompute a LayoutResult for the given score and configuration.
The result is independent of pixel dimensions so any renderer can consume it.