pub struct GlyphMetrics {
pub advance_mm: f32,
pub left_mm: f32,
pub top_mm: f32,
pub width_mm: f32,
pub height_mm: f32,
}Expand description
Font-independent metrics for one print glyph, expressed in millimetres.
Hosts may resolve a resource key to a real font, but layout can use these metrics without
loading fonts or depending on an operating system. advance_mm is the cursor advance;
the bounding box is relative to the glyph origin and is used for collision checks.
Fields
advance_mm: f32left_mm: f32top_mm: f32width_mm: f32height_mm: f32Trait Implementations
Sourceimpl Clone for GlyphMetrics
impl Clone for GlyphMetrics
Sourcefn clone(&self) -> GlyphMetrics
fn clone(&self) -> GlyphMetrics
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for GlyphMetrics
Sourceimpl Debug for GlyphMetrics
impl Debug for GlyphMetrics
Sourceimpl<'de> Deserialize<'de> for GlyphMetrics
impl<'de> Deserialize<'de> for GlyphMetrics
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for GlyphMetrics
impl PartialEq for GlyphMetrics
Sourceimpl Serialize for GlyphMetrics
impl Serialize for GlyphMetrics
impl StructuralPartialEq for GlyphMetrics