pub struct PublicationSpacer {
pub before_measure: usize,
pub height_mm: f32,
}Expand description
Extra vertical space inserted before the system that begins at one physical measure.
Spacers are publication policy, not score notation. Their height is consumed by pagination
and reflected in the following system’s top_mm.
Fields
before_measure: usizeZero-based physical measure at which the following system receives extra space.
height_mm: f32Trait Implementations
Sourceimpl Clone for PublicationSpacer
impl Clone for PublicationSpacer
Sourceimpl Debug for PublicationSpacer
impl Debug for PublicationSpacer
Sourceimpl<'de> Deserialize<'de> for PublicationSpacer
impl<'de> Deserialize<'de> for PublicationSpacer
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for PublicationSpacer
impl PartialEq for PublicationSpacer
Sourceimpl Serialize for PublicationSpacer
impl Serialize for PublicationSpacer
impl StructuralPartialEq for PublicationSpacer