Logical, pixel-free score layout engine for acorde-core
scores — computes row breaks, multi-rest collapsing, beam groups, tuplet groups, courtesy
accidentals, and span (hairpin/ottava/pedal/slur) resolution for score renderers (e.g. VexFlow).
Structs
- Beam
Group - A group of beamed notes within a single voice of a measure.
- Concert
KeyOverride - Concert-pitch key signature override for a specific staff of a transposing instrument.
- Courtesy
Accidental - A courtesy (cautionary) accidental to display in parentheses.
- Layout
Config - Configuration for a layout pass.
- Layout
Result - The result of a layout pass.
- Note
Addr - Physical address of a note within a score.
- RowLayout
- One horizontal row (system) of measures.
- Tuplet
Group - A group of notes forming one tuplet bracket within a single voice of one measure.
Enums
- Span
Mark - A resolved span between two note addresses.
Functions
- compute_
layout - Compute a
LayoutResultfor the given score and configuration.