Skip to main contentCrate acorde_layout
Source - BeamGroup
- A group of beamed notes within a single voice of a measure.
- ConcertKeyOverride
- Concert-pitch key signature override for a specific staff of a transposing instrument.
- CourtesyAccidental
- A courtesy (cautionary) accidental to display in parentheses.
- LayoutConfig
- Configuration for a layout pass.
- LayoutResult
- The result of a layout pass.
- NoteAddr
- Physical address of a note within a score.
- RowLayout
- One horizontal row (system) of measures.
- TupletGroup
- A group of notes forming one tuplet bracket within a single voice of one measure.
- SpanMark
- A resolved span between two note addresses.
- compute_layout
- Compute a
LayoutResult for the given score and configuration.