PublicationConfig

Struct PublicationConfig 

pub struct PublicationConfig {
Show 17 fields pub title_page: bool, pub running_title: Option<String>, pub show_part_names: bool, pub show_measure_numbers: bool, pub header_text: Option<String>, pub footer_text: Option<String>, pub header_template: PublicationPageTemplate, pub footer_template: PublicationPageTemplate, pub page_number_in_footer: bool, pub header_alignment: PublicationTextAlignment, pub footer_alignment: PublicationTextAlignment, pub title_alignment: PublicationTextAlignment, pub line_height_mm: f32, pub image_resources: Vec<PublicationImageResource>, pub sections: Vec<PublicationSection>, pub spacers: Vec<PublicationSpacer>, pub frames: Vec<PublicationFrame>,
}
Host-neutral publication metadata policy carried into each page artifact.

Fields

title_page: bool

Insert a metadata-only title page before the music pages.

running_title: Option<String>

Optional running title shown by a host on non-title pages.

show_part_names: boolshow_measure_numbers: boolheader_text: Option<String>

Optional text placed in the logical page header.

footer_text: Option<String>

Optional text placed in the logical page footer.

header_template: PublicationPageTemplate

Odd/even header text. When configured, this supersedes header_text and running_title.

footer_template: PublicationPageTemplate

Odd/even footer text. When configured, this supersedes footer_text.

page_number_in_footer: bool

Add the logical page number as a footer text block when numbering is enabled.

header_alignment: PublicationTextAlignmentfooter_alignment: PublicationTextAlignmenttitle_alignment: PublicationTextAlignmentline_height_mm: f32

Logical line-box height for publication text blocks, in millimetres.

image_resources: Vec<PublicationImageResource>

Host-resolved publication images carried as safe opaque references.

sections: Vec<PublicationSection>

Publication-only section headings and optional forced page starts.

spacers: Vec<PublicationSpacer>

Publication-only vertical gaps inserted before selected systems.

frames: Vec<PublicationFrame>

Host-rendered page frames with validated physical geometry.